@@ -79,15 +79,13 @@ class ThemedWindow ( HasPrivateTraits ):
     def capture_mouse ( self ):
         """ Grab control of the mouse and indicate that we are controlling it.
         """
-        if not self._has_capture:
-            self._has_capture = True
+        if not self.control.HasCapture():
             self.control.CaptureMouse()
 
     def release_mouse ( self ):
         """ Grab control of the mouse and indicate that we are controlling it.
         """
-        if self._has_capture:
-            self._has_capture = False
+        if self.control.HasCapture():
             self.control.ReleaseMouse()
 
     #-- Trait Event Handlers ---------------------------------------------------
@@ -184,10 +182,8 @@ class ThemedWindow ( HasPrivateTraits ):
     def _left_up ( self, event ):
         """ Handles a left mouse button up event.
         """
-        if self._has_capture:
-            self._has_capture = False
-            self.control.ReleaseMouse()
-            self._mouse_event( 'left_up', event )
+        self.release_mouse()
+        self._mouse_event( 'left_up', event )
 
     def _left_dclick ( self, event ):
         """ Handles a left mouse button double click event.
